@@ -1,4 +1,4 @@
-# Copyright (c) 2019, Adrian Dusa
+# Copyright (c) 2020, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,6 @@
 function(noflevels, arrange = FALSE, depth = NULL, raw = FALSE, ...) {
     result <- createMatrix(noflevels + 1, arrange = arrange, depth = depth, ... = ...) - 1
     attr(result, "raw") <- raw
-    class(result) <- c("matrix", "aE")
+    class(result) <- c("matrix", "QCA_aE")
     return(result)
 }
