@@ -1,4 +1,4 @@
-# Copyright (c) 2019, Adrian Dusa
+# Copyright (c) 2020, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -37,19 +37,17 @@ function(expression = "", obj, remainders = TRUE, type = 1, ...) {
         stop(simpleError("The truth table object is missing.\n\n"))
     }
     other.args <- list(...)
-    if (methods::is(obj, "tt")) {
+    if (methods::is(obj, "QCA_tt")) {
         noflevels <- obj$noflevels
         conditions <- obj$options$conditions
         if (any(is.element(type, c(0, 2, 3)))) {
             call <- as.list(obj$call)[-1]
             call$data <- obj$initial.data
-            if (obj$options$neg.out) {
-                if (admisc::tilde1st(call$outcome)) {
-                    call$outcome <- admisc::notilde(call$outcome)
-                }
+            if (admisc::tilde1st(call$outcome)) {
+                call$outcome <- admisc::notilde(call$outcome)
             }
             else {
-                call$outcome <- paste("~", call$outcome, sep = "")
+                call$outcome <- paste("~", call$outcome, sep = "")    
             }
             call$incl.cut <- rev(obj$options$incl.cut)
             if (length(other.args) > 0) {
@@ -107,7 +105,7 @@ function(expression = "", obj, remainders = TRUE, type = 1, ...) {
                 result <- rbind(result, rowi)
             }
         }
-        if (methods::is(obj, "tt")) {
+        if (methods::is(obj, "QCA_tt")) {
             mbase <- rev(c(1, cumprod(rev(noflevels))))[-1]
             diffwith <- NULL
             if (remainders) {
